@@ -14,6 +14,7 @@ OC.L10N.register(
     "Folder exists already!" : "Dosierujo jam ekzistas!",
     "Credentials" : "Aŭtentigiloj",
     "Subscribe" : "Aboni",
+    "Show all articles" : "Montri ĉiujn artikolojn",
     "Move" : "Movi",
     "Share" : "Kunhavigi",
     "Share with" : "Kunhavigi kun",
@@ -21,8 +22,8 @@ OC.L10N.register(
     "All articles" : "Ĉiuj artikoloj",
     "Starred" : "Markita",
     "Settings" : "Agordo",
+    "Documentation" : "Dokumentaro",
     "Keyboard shortcuts" : "Fulmoklavoj",
-    "Show all articles" : "Montri ĉiujn artikolojn",
     "Rename" : "Alinomigi",
     "Delete" : "Forigi",
     "Newest first" : "Pli novaj unue",
@@ -30,28 +31,10 @@ OC.L10N.register(
     "Mark unread" : "Marki kiel nelegita",
     "Close details" : "Fermi detalojn",
     "by" : "de",
-    "from" : "el",
     "Open website" : "Malfermi TTT-ejon",
     "Not available" : "Ne disponeble",
     "right" : "dekstro",
     "left" : "maldekstro",
-    "Refresh" : "Refreŝigi",
-    "Description" : "Priskribo",
-    "Folder" : "Dosierujo",
-    "Go back" : "Revenu",
-    "New Folder" : "Nova dosierujo",
-    "Create" : "Krei",
-    "Deleted feed" : "Forigis fluon",
-    "Undo delete feed" : "Malfari forigon de fluo",
-    "Dismiss" : "Forsendi",
-    "Collapse" : "Maletendi",
-    "Deleted folder" : "Foriĝis dosierujo",
-    "Undo delete folder" : "Malfari forigon de dosierujo",
-    "Import" : "Enporti",
-    "Export" : "Elporti",
-    "Error when importing: file does not contain valid JSON" : "La enporto eraris: la dosiero ne enhavas validan JSON-on",
-    "Help" : "Helpo",
-    "Documentation" : "Dokumentaro",
-    "Report a bug" : "Raporti problemon"
+    "Refresh" : "Refreŝigi"
 },
 "nplurals=2; plural=(n != 1);");
